==> beast-cart-api-2.2.6-sources.jar: com/thebeastshop/cart/model/gift/ScGiftSpvVO.java <==
package com.thebeastshop.cart.model.gift;

import com.thebeastshop.cart.model.ScBrand;
import com.thebeastshop.cart.model.ScSpvVO;
import com.thebeastshop.common.BaseDO;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author feiLong.gao
 * @date 2019/12/25
 */
public class ScGiftSpvVO extends BaseDO {

    private Long id;                      // spvId
    private String name;                     // 商品名字
    private String image;                    // 默认spv图片
    private ScBrand brand = new ScBrand();      //品牌
    private String spvDesc;                    // spv描述信息：这里包含规格信息
    private List<String> skuCodes;           // 商品skuCode列表
    private Integer maximum;                // 最大可选件数
    private Integer minAmount =1;           // 最小购买数，每件赠品，对应spv数量
    private Integer left;                   // 库存数：剩余赠品数和实际商品数，取最小值
    private Boolean soldOut;                // 是否售罄，售罄标识已赠完
    private Integer customPrintTemplate;    // 定制卡片模板
    private BigDecimal price = BigDecimal.ZERO;  // spv价格
    private BigDecimal rawPrice = BigDecimal.ZERO;  // spv源价格

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getImage() {
        return image;
    }

    public ScBrand getBrand() {
        return brand;
    }

    public void setBrand(ScBrand brand) {
        this.brand = brand;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSpvDesc() {
        return spvDesc;
    }

    public void setSpvDesc(String spvDesc) {
        this.spvDesc = spvDesc;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public Integer getMaximum() {
        return maximum;
    }

    public void setMaximum(Integer maximum) {
        this.maximum = maximum;
    }

    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public Integer getLeft() {
        return left;
    }

    public void setLeft(Integer left) {
        this.left = left;
    }

    public Integer getCustomPrintTemplate() {
        return customPrintTemplate;
    }

    public void setCustomPrintTemplate(Integer customPrintTemplate) {
        this.customPrintTemplate = customPrintTemplate;
    }

    public Boolean getSoldOut() {
        return soldOut;
    }

    public void setSoldOut(Boolean soldOut) {
        this.soldOut = soldOut;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getRawPrice() {
        return rawPrice;
    }

    public void setRawPrice(BigDecimal rawPrice) {
        this.rawPrice = rawPrice;
    }
}

==> beast-cart-api-2.3.9-20251210.093703-1-sources.jar: com/thebeastshop/cart/model/gift/ScGiftSpvVO.java <==
package com.thebeastshop.cart.model.gift;

import com.thebeastshop.cart.model.ScBrand;
import com.thebeastshop.common.BaseDO;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author feiLong.gao
 * @date 2019/12/25
 */
public class ScGiftSpvVO extends BaseDO {

    private static final long serialVersionUID = 8970620302207782326L;
    private Long id;                      // spvId
    private String name;                     // 商品名字
    private String image;                    // 默认spv图片
    private ScBrand brand = new ScBrand();      //品牌
    private String spvDesc;                    // spv描述信息：这里包含规格信息
    private List<String> skuCodes;           // 商品skuCode列表
    private Integer maximum;                // 最大可选件数
    private Integer minAmount =1;           // 最小购买数，每件赠品，对应spv数量
    private Integer left;                   // 库存数：剩余赠品数和实际商品数，取最小值
    private Boolean soldOut;                // 是否售罄，售罄标识已赠完
    private Integer customPrintTemplate;    // 定制卡片模板
    private BigDecimal price = BigDecimal.ZERO;  // spv价格
    private BigDecimal rawPrice = BigDecimal.ZERO;  // spv源价格

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getImage() {
        return image;
    }

    public ScBrand getBrand() {
        return brand;
    }

    public void setBrand(ScBrand brand) {
        this.brand = brand;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSpvDesc() {
        return spvDesc;
    }

    public void setSpvDesc(String spvDesc) {
        this.spvDesc = spvDesc;
    }

    public List<String> getSkuCodes() {
        return skuCodes;
    }

    public void setSkuCodes(List<String> skuCodes) {
        this.skuCodes = skuCodes;
    }

    public Integer getMaximum() {
        return maximum;
    }

    public void setMaximum(Integer maximum) {
        this.maximum = maximum;
    }

    public Integer getMinAmount() {
        return minAmount;
    }

    public void setMinAmount(Integer minAmount) {
        this.minAmount = minAmount;
    }

    public Integer getLeft() {
        return left;
    }

    public void setLeft(Integer left) {
        this.left = left;
    }

    public Integer getCustomPrintTemplate() {
        return customPrintTemplate;
    }

    public void setCustomPrintTemplate(Integer customPrintTemplate) {
        this.customPrintTemplate = customPrintTemplate;
    }

    public Boolean getSoldOut() {
        return soldOut;
    }

    public void setSoldOut(Boolean soldOut) {
        this.soldOut = soldOut;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getRawPrice() {
        return rawPrice;
    }

    public void setRawPrice(BigDecimal rawPrice) {
        this.rawPrice = rawPrice;
    }
}
